@@ -1,18 +1,21 @@
 import os
 import uuid
-from time import sleep
+from ipaddress import IPv4Address
 from unittest import SkipTest, mock
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
-from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives import serialization
+from cryptography.x509 import (
+    IPAddress,
+    SubjectAlternativeName,
+    load_pem_x509_certificate,
+)
 from freezegun import freeze_time
 
-from moto import mock_acm, mock_elb, settings
-from moto.acm.models import AWS_ROOT_CA
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from tests.test_elbv2.test_elbv2 import create_load_balancer
 
 RESOURCE_FOLDER = os.path.join(os.path.dirname(__file__), "resources")
 
@@ -28,6 +31,7 @@ SERVER_COMMON_NAME = "*.moto.com"
 SERVER_CRT_BAD = get_resource("star_moto_com-bad.pem")
 SERVER_KEY = get_resource("star_moto_com.key")
 BAD_ARN = f"arn:aws:acm:us-east-2:{ACCOUNT_ID}:certificate/_0000000-0000-0000-0000-000000000000"
+CERT_AUTH_ARN = f"arn:aws:acm-pca:eu-central-1:{ACCOUNT_ID}:certificate-authority/12345678-1234-1234-1234-123456789012"
 
 
 def _import_cert(client):
@@ -37,8 +41,15 @@ def _import_cert(client):
     return response["CertificateArn"]
 
 
+def _pca_cert(client):
+    response = client.request_certificate(
+        DomainName=SERVER_COMMON_NAME, CertificateAuthorityArn=CERT_AUTH_ARN
+    )
+    return response["CertificateArn"]
+
+
 # Also tests GetCertificate
-@mock_acm
+@mock_aws
 def test_import_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -51,7 +62,7 @@ def test_import_certificate():
     assert "CertificateChain" in resp
 
 
-@mock_acm
+@mock_aws
 def test_import_certificate_with_tags():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -75,7 +86,7 @@ def test_import_certificate_with_tags():
     assert tags["KeyOnly"] == "__NONE__"
 
 
-@mock_acm
+@mock_aws
 def test_import_bad_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -87,7 +98,7 @@ def test_import_bad_certificate():
         raise RuntimeError("Should have raised ValidationException")
 
 
-@mock_acm
+@mock_aws
 def test_list_certificates():
     client = boto3.client("acm", region_name="eu-central-1")
     issued_arn = _import_cert(client)
@@ -131,7 +142,7 @@ def test_list_certificates():
     assert pending_arn in [c["CertificateArn"] for c in certs]
 
 
-@mock_acm
+@mock_aws
 def test_get_invalid_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -144,7 +155,7 @@ def test_get_invalid_certificate():
 
 
 # Also tests deleting invalid certificate
-@mock_acm
+@mock_aws
 def test_delete_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
@@ -160,8 +171,64 @@ def test_delete_certificate():
         raise RuntimeError("Should have raised ResourceNotFoundException")
 
 
-@mock_acm
+@mock_aws
+def test_request_certificate_for_ip():
+    client = boto3.client("acm", region_name="eu-central-1")
+    arn = client.request_certificate(DomainName="10.0.0.1")["CertificateArn"]
+
+    try:
+        cert_arn = client.describe_certificate(CertificateArn=arn)["Certificate"][
+            "CertificateArn"
+        ]
+    except OverflowError:
+        pytest.skip("This test requires 64-bit time_t")
+
+    resp = client.get_certificate(CertificateArn=cert_arn)
+
+    cert = load_pem_x509_certificate(resp["Certificate"].encode("utf-8"))
+    san = cert.extensions[0].value
+    assert isinstance(san, SubjectAlternativeName)
+
+    ip_address = san.get_values_for_type(IPAddress)[0]
+    assert isinstance(ip_address, IPv4Address)
+    assert ip_address.compressed == "10.0.0.1"
+
+
+@mock_aws
 def test_describe_certificate():
+    client = boto3.client("acm", region_name="eu-central-1")
+    arn = client.request_certificate(DomainName=SERVER_COMMON_NAME)["CertificateArn"]
+
+    try:
+        resp = client.describe_certificate(CertificateArn=arn)
+    except OverflowError:
+        pytest.skip("This test requires 64-bit time_t")
+    assert resp["Certificate"]["CertificateArn"] == arn
+    assert resp["Certificate"]["DomainName"] == SERVER_COMMON_NAME
+    assert resp["Certificate"]["Issuer"] == "Amazon"
+    assert resp["Certificate"]["KeyAlgorithm"] == "RSA_2048"
+    assert resp["Certificate"]["Status"] == "PENDING_VALIDATION"
+    assert resp["Certificate"]["Type"] == "AMAZON_ISSUED"
+    assert resp["Certificate"]["RenewalEligibility"] == "INELIGIBLE"
+    assert "Options" in resp["Certificate"]
+
+    assert len(resp["Certificate"]["DomainValidationOptions"]) == 1
+    validation_option = resp["Certificate"]["DomainValidationOptions"][0]
+    assert validation_option["DomainName"] == SERVER_COMMON_NAME
+
+
+@mock_aws
+def test_describe_certificate_with_bad_arn():
+    client = boto3.client("acm", region_name="eu-central-1")
+
+    with pytest.raises(ClientError) as err:
+        client.describe_certificate(CertificateArn=BAD_ARN)
+
+    assert err.value.response["Error"]["Code"] == "ResourceNotFoundException"
+
+
+@mock_aws
+def test_describe_certificate_with_imported_cert():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
 
@@ -178,44 +245,62 @@ def test_describe_certificate():
     assert resp["Certificate"]["RenewalEligibility"] == "INELIGIBLE"
     assert "Options" in resp["Certificate"]
 
-    assert len(resp["Certificate"]["DomainValidationOptions"]) == 1
-    validation_option = resp["Certificate"]["DomainValidationOptions"][0]
-    assert validation_option["DomainName"] == SERVER_COMMON_NAME
+    assert "DomainValidationOptions" not in resp["Certificate"]
 
 
-@mock_acm
-def test_describe_certificate_with_bad_arn():
+@mock_aws
+def test_describe_certificate_with_pca_cert():
     client = boto3.client("acm", region_name="eu-central-1")
-
-    with pytest.raises(ClientError) as err:
-        client.describe_certificate(CertificateArn=BAD_ARN)
-
-    assert err.value.response["Error"]["Code"] == "ResourceNotFoundException"
+    arn = _pca_cert(client)
+    try:
+        resp = client.describe_certificate(CertificateArn=arn)
+    except OverflowError:
+        pytest.skip("This test requires 64-bit time_t")
+    assert resp["Certificate"]["CertificateArn"] == arn
+    assert resp["Certificate"]["DomainName"] == SERVER_COMMON_NAME
+    assert resp["Certificate"]["Issuer"] == "Amazon"
+    assert resp["Certificate"]["KeyAlgorithm"] == "RSA_2048"
+    assert resp["Certificate"]["Status"] == "PENDING_VALIDATION"
+    assert resp["Certificate"]["Type"] == "PRIVATE"
+    assert resp["Certificate"]["RenewalEligibility"] == "INELIGIBLE"
+    assert "Options" in resp["Certificate"]
+    assert resp["Certificate"]["CertificateAuthorityArn"] == CERT_AUTH_ARN
+    assert "DomainValidationOptions" not in resp["Certificate"]
 
 
-@mock_acm
-def test_export_certificate():
+@mock_aws
+def test_export_certificate_with_pca_cert():
+    client = boto3.client("acm", region_name="eu-central-1")
+    arn = _pca_cert(client)
+    resp = client.export_certificate(CertificateArn=arn, Passphrase="passphrase")
+    assert "CertificateChain" in resp
+    assert "Certificate" in resp
+    assert "PrivateKey" in resp
+
+
+@mock_aws
+def test_export_certificate_with_imported_cert():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
 
-    resp = client.export_certificate(CertificateArn=arn, Passphrase="pass")
-    assert resp["Certificate"] == SERVER_CRT.decode()
-    assert resp["CertificateChain"] == CA_CRT.decode() + "\n" + AWS_ROOT_CA.decode()
-    assert "PrivateKey" in resp
-
-    key = serialization.load_pem_private_key(
-        bytes(resp["PrivateKey"], "utf-8"), password=b"pass", backend=default_backend()
-    )
-
-    private_key = key.private_bytes(
-        encoding=serialization.Encoding.PEM,
-        format=serialization.PrivateFormat.TraditionalOpenSSL,
-        encryption_algorithm=serialization.NoEncryption(),
-    )
-    assert private_key == SERVER_KEY
+    with pytest.raises(ClientError) as err:
+        client.export_certificate(CertificateArn=arn, Passphrase="passphrase")
+    assert err.value.response["Error"]["Code"] == "ValidationException"
+    assert "is not a private certificate" in err.value.response["Error"]["Message"]
 
 
-@mock_acm
+@mock_aws
+def test_export_certificate_with_short_passphrase():
+    client = boto3.client("acm", region_name="eu-central-1")
+    arn = _pca_cert(client)
+
+    with pytest.raises(ClientError) as err:
+        client.export_certificate(CertificateArn=arn, Passphrase="")
+    assert err.value.response["Error"]["Code"] == "ValidationException"
+    assert "passphrase" in err.value.response["Error"]["Message"]
+
+
+@mock_aws
 def test_export_certificate_with_bad_arn():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -226,7 +311,7 @@ def test_export_certificate_with_bad_arn():
 
 
 # Also tests ListTagsForCertificate
-@mock_acm
+@mock_aws
 def test_add_tags_to_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
@@ -247,7 +332,7 @@ def test_add_tags_to_certificate():
     assert tags["key2"] == "__NONE__"
 
 
-@mock_acm
+@mock_aws
 def test_add_tags_to_invalid_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -262,7 +347,7 @@ def test_add_tags_to_invalid_certificate():
         raise RuntimeError("Should have raised ResourceNotFoundException")
 
 
-@mock_acm
+@mock_aws
 def test_list_tags_for_invalid_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -274,7 +359,7 @@ def test_list_tags_for_invalid_certificate():
         raise RuntimeError("Should have raised ResourceNotFoundException")
 
 
-@mock_acm
+@mock_aws
 def test_remove_tags_from_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
@@ -308,7 +393,7 @@ def test_remove_tags_from_certificate():
     assert "key1" in tags
 
 
-@mock_acm
+@mock_aws
 def test_remove_tags_from_invalid_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -323,7 +408,7 @@ def test_remove_tags_from_invalid_certificate():
         raise RuntimeError("Should have raised ResourceNotFoundException")
 
 
-@mock_acm
+@mock_aws
 def test_resend_validation_email():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
@@ -334,7 +419,7 @@ def test_resend_validation_email():
     # Returns nothing, boto would raise Exceptions otherwise
 
 
-@mock_acm
+@mock_aws
 def test_resend_validation_email_invalid():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
@@ -364,7 +449,7 @@ def test_resend_validation_email_invalid():
         raise RuntimeError("Should have raised ResourceNotFoundException")
 
 
-@mock_acm
+@mock_aws
 def test_request_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -387,7 +472,7 @@ def test_request_certificate():
     assert resp["CertificateArn"] == arn
 
 
-@mock_acm
+@mock_aws
 @mock.patch("moto.settings.ACM_VALIDATION_WAIT", 1)
 def test_request_certificate_with_optional_arguments():
     if not settings.TEST_DECORATOR_MODE:
@@ -418,9 +503,11 @@ def test_request_certificate_with_optional_arguments():
     )
 
     # Verify SAN's are still the same, even after the Certificate is validated
-    sleep(2)
+    waiter = client.get_waiter("certificate_validated")
+    waiter.wait(CertificateArn=arn_1, WaiterConfig={"Delay": 1})
+
     for opt in validation_options:
-        opt["ValidationStatus"] = "ISSUED"
+        opt["ValidationStatus"] = "SUCCESS"
     cert = client.describe_certificate(CertificateArn=arn_1)["Certificate"]
     assert cert["DomainValidationOptions"] == validation_options
 
@@ -470,7 +557,18 @@ def test_request_certificate_with_optional_arguments():
     assert arn_1 != arn_4  # if tags are matched, ACM would have returned same arn
 
 
-@mock_acm
+@mock_aws
+def test_request_certificate_with_certificate_authority():
+    client = boto3.client("acm", region_name="eu-central-1")
+
+    resp = client.request_certificate(
+        DomainName="example.com",
+        CertificateAuthorityArn="arn:aws:acm-pca:eu-central-1:123456789012:certificate-authority/12345678-1234-1234-1234-123456789012",
+    )
+    assert "CertificateArn" in resp
+
+
+@mock_aws
 def test_operations_with_invalid_tags():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -521,7 +619,7 @@ def test_operations_with_invalid_tags():
     assert "AWS internal tags cannot be changed with this API" in err["Message"]
 
 
-@mock_acm
+@mock_aws
 def test_add_too_many_tags():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
@@ -554,7 +652,7 @@ def test_add_too_many_tags():
     assert len(client.list_tags_for_certificate(CertificateArn=arn)["Tags"]) == 49
 
 
-@mock_acm
+@mock_aws
 def test_request_certificate_no_san():
     client = boto3.client("acm", region_name="eu-central-1")
 
@@ -574,7 +672,7 @@ def test_request_certificate_no_san():
 
 
 # Also tests the SAN code
-@mock_acm
+@mock_aws
 def test_request_certificate_issued_status():
     # After requesting a certificate, it should then auto-validate after 1 minute
     # Some sneaky programming for that ;-)
@@ -612,7 +710,7 @@ def test_request_certificate_issued_status():
 
 
 @mock.patch("moto.settings.ACM_VALIDATION_WAIT", 3)
-@mock_acm
+@mock_aws
 def test_request_certificate_issued_status_with_wait_in_envvar():
     # After requesting a certificate, it should then auto-validate after 3 seconds
     if not settings.TEST_DECORATOR_MODE:
@@ -641,8 +739,8 @@ def test_request_certificate_issued_status_with_wait_in_envvar():
     assert resp["Certificate"]["Status"] == "ISSUED"
 
 
-@mock_acm
-def test_request_certificate_with_mutiple_times():
+@mock_aws
+def test_request_certificate_with_multiple_times():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cant manipulate time in server mode")
 
@@ -689,8 +787,7 @@ def test_request_certificate_with_mutiple_times():
     assert arn != original_arn
 
 
-@mock_acm
-@mock_elb
+@mock_aws
 def test_elb_acm_in_use_by():
     acm_client = boto3.client("acm", region_name="us-west-2")
     elb_client = boto3.client("elb", region_name="us-west-2")
@@ -722,3 +819,44 @@ def test_elb_acm_in_use_by():
     assert response["Certificate"]["InUseBy"] == [
         create_load_balancer_request["DNSName"]
     ]
+
+    certificates = acm_client.list_certificates()["CertificateSummaryList"]
+    cert = [
+        _cert for _cert in certificates if _cert["CertificateArn"] == certificate_arn
+    ][0]
+    assert cert["InUse"]
+
+
+@mock_aws
+def test_elbv2_acm_in_use_by():
+    acm_client = boto3.client("acm", region_name="us-east-1")
+
+    certificate_arn = acm_client.request_certificate(
+        DomainName="fake.domain.com",
+        DomainValidationOptions=[
+            {"DomainName": "fake.domain.com", "ValidationDomain": "domain.com"}
+        ],
+    )["CertificateArn"]
+
+    response, _, _, _, _, elbv2_client = create_load_balancer()
+    load_balancer_arn = response["LoadBalancers"][0]["LoadBalancerArn"]
+
+    create_listener_resp = elbv2_client.create_listener(
+        LoadBalancerArn=load_balancer_arn,
+        Protocol="HTTP",
+        Port=443,
+        DefaultActions=[],
+        Certificates=[{"CertificateArn": certificate_arn}],
+        AlpnPolicy=["pol1", "pol2"],
+    )
+
+    response = acm_client.describe_certificate(CertificateArn=certificate_arn)
+    assert response["Certificate"]["InUseBy"] == [
+        create_listener_resp["Listeners"][0]["ListenerArn"]
+    ]
+
+    certificates = acm_client.list_certificates()["CertificateSummaryList"]
+    cert = [
+        _cert for _cert in certificates if _cert["CertificateArn"] == certificate_arn
+    ][0]
+    assert cert["InUse"]
