@@ -1,36 +1,42 @@
-import boto3
 import json
-import pytest
+import sys
 import time
 import uuid
+from unittest import SkipTest
 
+import boto3
+import pytest
 from botocore.exceptions import ClientError
-from moto import mock_dynamodb, mock_lambda, mock_logs, mock_sns, mock_sqs
-from uuid import uuid4
+
+from moto import mock_aws
+from moto.utilities.distutils_version import LooseVersion
+
+from ..markers import requires_docker
 from .utilities import (
     get_role_name,
     get_test_zip_file3,
-    wait_for_log_msg,
     get_test_zip_file_error,
+    wait_for_log_msg,
 )
-from ..markers import requires_docker
 
+PYTHON_VERSION = "python3.11"
 _lambda_region = "us-west-2"
-boto3.setup_default_session(region_name=_lambda_region)
+botocore_version = sys.modules["botocore"].__version__
 
 
-@mock_logs
-@mock_lambda
-@mock_sqs
+@mock_aws
 def test_create_event_source_mapping():
-    function_name = str(uuid4())[0:6]
+    if LooseVersion(botocore_version) < LooseVersion("1.23.12"):
+        raise SkipTest("Parameter FilterCriteria is not available in older versions")
+
+    function_name = str(uuid.uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
 
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -40,30 +46,98 @@ def test_create_event_source_mapping():
         Publish=True,
     )
 
+    destination_config = {
+        "OnSuccess": {"Destination": "s3"},
+        "OnFailure": {"Destination": "s4"},
+    }
+    doc_db_config = {
+        "DatabaseName": "db",
+        "CollectionName": "cn",
+        "FullDocument": "UpdateLookup",
+    }
     response = conn.create_event_source_mapping(
-        EventSourceArn=queue.attributes["QueueArn"], FunctionName=func["FunctionArn"]
+        EventSourceArn=queue.attributes["QueueArn"],
+        FunctionName=func["FunctionArn"],
+        BatchSize=1,
+        FilterCriteria={
+            "Filters": [{"Pattern": r"asdf"}],
+        },
+        MaximumBatchingWindowInSeconds=5,
+        ParallelizationFactor=4,
+        StartingPosition="AT_TIMESTAMP",
+        DestinationConfig=destination_config,
+        MaximumRecordAgeInSeconds=59,
+        BisectBatchOnFunctionError=True,
+        MaximumRetryAttempts=9000,
+        Tags={"k1": "v1"},
+        TumblingWindowInSeconds=100,
+        Topics=["t1", "T2"],
+        Queues=["q1", "q2"],
+        SourceAccessConfigurations=[
+            {"Type": "BASIC_AUTH", "URI": "http://auth.endpoint"},
+        ],
+        SelfManagedEventSource={
+            "Endpoints": {
+                "key": ["v1"],
+            },
+        },
+        FunctionResponseTypes=["ReportBatchItemFailures"],
+        AmazonManagedKafkaEventSourceConfig={"ConsumerGroupId": "cgid"},
+        SelfManagedKafkaEventSourceConfig={"ConsumerGroupId": "cgid2"},
+        ScalingConfig={"MaximumConcurrency": 100},
+        DocumentDBEventSourceConfig=doc_db_config,
+        KMSKeyArn="arn:kms:key",
+        MetricsConfig={"Metrics": ["EventCount"]},
+        ProvisionedPollerConfig={"MinimumPollers": 12, "MaximumPollers": 13},
     )
 
     assert response["EventSourceArn"] == queue.attributes["QueueArn"]
     assert response["FunctionArn"] == func["FunctionArn"]
     assert response["State"] == "Enabled"
+    assert response["BatchSize"] == 1
+    assert response["StartingPosition"] == "AT_TIMESTAMP"
+    assert response["MaximumBatchingWindowInSeconds"] == 5
+    assert response["ParallelizationFactor"] == 4
+    assert response["FilterCriteria"] == {"Filters": [{"Pattern": "asdf"}]}
+    assert response["DestinationConfig"] == destination_config
+    assert response["Topics"] == ["t1", "T2"]
+    assert response["Queues"] == ["q1", "q2"]
+    assert response["SourceAccessConfigurations"] == [
+        {"Type": "BASIC_AUTH", "URI": "http://auth.endpoint"}
+    ]
+    assert response["SelfManagedEventSource"] == {"Endpoints": {"key": ["v1"]}}
+    assert response["MaximumRecordAgeInSeconds"] == 59
+    assert response["BisectBatchOnFunctionError"] is True
+    assert response["MaximumRetryAttempts"] == 9000
+    assert response["TumblingWindowInSeconds"] == 100
+    assert response["FunctionResponseTypes"] == ["ReportBatchItemFailures"]
+    assert response["AmazonManagedKafkaEventSourceConfig"] == {
+        "ConsumerGroupId": "cgid"
+    }
+    assert response["SelfManagedKafkaEventSourceConfig"] == {"ConsumerGroupId": "cgid2"}
+    assert response["ScalingConfig"] == {"MaximumConcurrency": 100}
+    assert response["DocumentDBEventSourceConfig"] == doc_db_config
+    assert response["KMSKeyArn"] == "arn:kms:key"
+    assert response["MetricsConfig"] == {"Metrics": ["EventCount"]}
+    assert response["ProvisionedPollerConfig"] == {
+        "MinimumPollers": 12,
+        "MaximumPollers": 13,
+    }
 
 
 @pytest.mark.network
 @pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
-@mock_logs
-@mock_lambda
-@mock_sqs
+@mock_aws
 @requires_docker
 def test_invoke_function_from_sqs(key):
-    function_name = str(uuid4())[0:6]
+    function_name = str(uuid.uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
 
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -96,13 +170,11 @@ def test_invoke_function_from_sqs(key):
 
 
 @pytest.mark.network
-@mock_logs
-@mock_lambda
-@mock_dynamodb
+@mock_aws
 @requires_docker
 def test_invoke_function_from_dynamodb_put():
     dynamodb = boto3.client("dynamodb", region_name="us-east-1")
-    table_name = str(uuid4())[0:6] + "_table"
+    table_name = str(uuid.uuid4())[0:6] + "_table"
     table = dynamodb.create_table(
         TableName=table_name,
         KeySchema=[{"AttributeName": "id", "KeyType": "HASH"}],
@@ -115,10 +187,10 @@ def test_invoke_function_from_dynamodb_put():
     )
 
     conn = boto3.client("lambda", region_name="us-east-1")
-    function_name = str(uuid4())[0:6]
+    function_name = str(uuid.uuid4())[0:6]
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -152,13 +224,11 @@ def test_invoke_function_from_dynamodb_put():
 
 
 @pytest.mark.network
-@mock_logs
-@mock_lambda
-@mock_dynamodb
+@mock_aws
 @requires_docker
 def test_invoke_function_from_dynamodb_update():
     dynamodb = boto3.client("dynamodb", region_name="us-east-1")
-    table_name = str(uuid4())[0:6] + "_table"
+    table_name = str(uuid.uuid4())[0:6] + "_table"
     table = dynamodb.create_table(
         TableName=table_name,
         KeySchema=[{"AttributeName": "id", "KeyType": "HASH"}],
@@ -171,10 +241,10 @@ def test_invoke_function_from_dynamodb_update():
     )
 
     conn = boto3.client("lambda", region_name="us-east-1")
-    function_name = str(uuid4())[0:6]
+    function_name = str(uuid.uuid4())[0:6]
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -214,12 +284,10 @@ def test_invoke_function_from_dynamodb_update():
 
 
 @pytest.mark.network
-@mock_logs
-@mock_lambda
-@mock_sqs
+@mock_aws
 @requires_docker
 def test_invoke_function_from_sqs_exception():
-    function_name = str(uuid4())[0:6]
+    function_name = str(uuid.uuid4())[0:6]
     logs_conn = boto3.client("logs", region_name="us-east-1")
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
@@ -227,7 +295,7 @@ def test_invoke_function_from_sqs_exception():
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file_error()},
@@ -279,9 +347,7 @@ def test_invoke_function_from_sqs_exception():
 
 
 @pytest.mark.network
-@mock_logs
-@mock_sns
-@mock_lambda
+@mock_aws
 @requires_docker
 def test_invoke_function_from_sns():
     logs_conn = boto3.client("logs", region_name=_lambda_region)
@@ -292,10 +358,10 @@ def test_invoke_function_from_sns():
     topic_arn = topics[0]["TopicArn"]
 
     conn = boto3.client("lambda", _lambda_region)
-    function_name = str(uuid4())[0:6]
+    function_name = str(uuid.uuid4())[0:6]
     result = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -309,7 +375,7 @@ def test_invoke_function_from_sns():
         TopicArn=topic_arn, Protocol="lambda", Endpoint=result["FunctionArn"]
     )
 
-    result = sns_conn.publish(TopicArn=topic_arn, Message=json.dumps({}))
+    sns_conn.publish(TopicArn=topic_arn, Message=json.dumps({}))
 
     start = time.time()
     events = []
@@ -337,18 +403,72 @@ def test_invoke_function_from_sns():
     assert False, "Expected message not found in logs:" + str(events)
 
 
-@mock_logs
-@mock_lambda
-@mock_sqs
+@pytest.mark.network
+@mock_aws
+@requires_docker
+def test_invoke_function_from_kinesis():
+    logs_conn = boto3.client("logs", region_name=_lambda_region)
+    kinesis = boto3.client("kinesis", region_name=_lambda_region)
+    stream_name = "my_stream"
+
+    kinesis.create_stream(StreamName=stream_name, ShardCount=2)
+    resp = kinesis.describe_stream(StreamName=stream_name)
+    kinesis_arn = resp["StreamDescription"]["StreamARN"]
+
+    conn = boto3.client("lambda", _lambda_region)
+    function_name = str(uuid.uuid4())[0:6]
+    func = conn.create_function(
+        FunctionName=function_name,
+        Runtime=PYTHON_VERSION,
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": get_test_zip_file3()},
+    )
+
+    conn.create_event_source_mapping(
+        EventSourceArn=kinesis_arn,
+        FunctionName=func["FunctionArn"],
+    )
+
+    # Send Data
+    kinesis.put_record(StreamName=stream_name, Data="data", PartitionKey="1")
+
+    start = time.time()
+    events = []
+    while (time.time() - start) < 10:
+        result = logs_conn.describe_log_streams(
+            logGroupName=f"/aws/lambda/{function_name}"
+        )
+        log_streams = result.get("logStreams")
+        if not log_streams:
+            time.sleep(1)
+            continue
+
+        assert len(log_streams) == 1
+        result = logs_conn.get_log_events(
+            logGroupName=f"/aws/lambda/{function_name}",
+            logStreamName=log_streams[0]["logStreamName"],
+        )
+        events = result.get("events")
+        for event in events:
+            if event["message"] == "get_test_zip_file3 success":
+                return
+
+        time.sleep(0.5)
+
+    assert False, "Expected message not found in logs:" + str(events)
+
+
+@mock_aws
 def test_list_event_source_mappings():
-    function_name = str(uuid4())[0:6]
+    function_name = str(uuid.uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
 
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -371,17 +491,16 @@ def test_list_event_source_mappings():
     assert mappings["EventSourceMappings"][0]["FunctionArn"] == func["FunctionArn"]
 
 
-@mock_lambda
-@mock_sqs
+@mock_aws
 def test_get_event_source_mapping():
-    function_name = str(uuid4())[0:6]
+    function_name = str(uuid.uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
 
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -397,21 +516,26 @@ def test_get_event_source_mapping():
     assert mapping["UUID"] == response["UUID"]
     assert mapping["FunctionArn"] == func["FunctionArn"]
 
-    with pytest.raises(ClientError):
+    with pytest.raises(ClientError) as exc:
         conn.get_event_source_mapping(UUID="1")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "The resource you requested does not exist."
 
 
-@mock_lambda
-@mock_sqs
+@mock_aws
 def test_update_event_source_mapping():
-    function_name = str(uuid4())[0:6]
+    if LooseVersion(botocore_version) < LooseVersion("1.23.12"):
+        raise SkipTest("Parameter FilterCriteria is not available in older versions")
+
+    function_name = str(uuid.uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
 
     conn = boto3.client("lambda", region_name="us-east-1")
     func1 = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -422,7 +546,7 @@ def test_update_event_source_mapping():
     )
     func2 = conn.create_function(
         FunctionName="testFunction2",
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -438,26 +562,78 @@ def test_update_event_source_mapping():
     assert response["BatchSize"] == 10
     assert response["State"] == "Enabled"
 
+    destination_config = {
+        "OnSuccess": {"Destination": "s3"},
+        "OnFailure": {"Destination": "s4"},
+    }
+    doc_db_config = {
+        "DatabaseName": "db",
+        "CollectionName": "cn",
+        "FullDocument": "UpdateLookup",
+    }
+
     mapping = conn.update_event_source_mapping(
-        UUID=response["UUID"], Enabled=False, BatchSize=2, FunctionName="testFunction2"
+        UUID=response["UUID"],
+        Enabled=False,
+        BatchSize=2,
+        FunctionName="testFunction2",
+        FilterCriteria={
+            "Filters": [{"Pattern": r"asdf"}],
+        },
+        MaximumBatchingWindowInSeconds=5,
+        ParallelizationFactor=4,
+        DestinationConfig=destination_config,
+        MaximumRecordAgeInSeconds=59,
+        BisectBatchOnFunctionError=True,
+        MaximumRetryAttempts=9000,
+        TumblingWindowInSeconds=100,
+        SourceAccessConfigurations=[
+            {"Type": "BASIC_AUTH", "URI": "http://auth.endpoint"},
+        ],
+        FunctionResponseTypes=["ReportBatchItemFailures"],
+        ScalingConfig={"MaximumConcurrency": 100},
+        DocumentDBEventSourceConfig=doc_db_config,
+        KMSKeyArn="arn:kms:key",
+        MetricsConfig={"Metrics": ["EventCount"]},
+        ProvisionedPollerConfig={"MinimumPollers": 12, "MaximumPollers": 13},
     )
     assert mapping["UUID"] == response["UUID"]
     assert mapping["FunctionArn"] == func2["FunctionArn"]
     assert mapping["State"] == "Disabled"
     assert mapping["BatchSize"] == 2
 
+    assert mapping["MaximumBatchingWindowInSeconds"] == 5
+    assert mapping["ParallelizationFactor"] == 4
+    assert mapping["FilterCriteria"] == {"Filters": [{"Pattern": "asdf"}]}
+    assert mapping["DestinationConfig"] == destination_config
+    assert mapping["SourceAccessConfigurations"] == [
+        {"Type": "BASIC_AUTH", "URI": "http://auth.endpoint"}
+    ]
+    assert mapping["MaximumRecordAgeInSeconds"] == 59
+    assert mapping["BisectBatchOnFunctionError"] is True
+    assert mapping["MaximumRetryAttempts"] == 9000
+    assert mapping["TumblingWindowInSeconds"] == 100
+    assert mapping["FunctionResponseTypes"] == ["ReportBatchItemFailures"]
+    assert mapping["ScalingConfig"] == {"MaximumConcurrency": 100}
+    assert mapping["DocumentDBEventSourceConfig"] == doc_db_config
+    assert mapping["KMSKeyArn"] == "arn:kms:key"
+    assert mapping["MetricsConfig"] == {"Metrics": ["EventCount"]}
+    assert mapping["ProvisionedPollerConfig"] == {
+        "MinimumPollers": 12,
+        "MaximumPollers": 13,
+    }
 
-@mock_lambda
-@mock_sqs
+
+@mock_aws
 def test_delete_event_source_mapping():
-    function_name = str(uuid4())[0:6]
+    function_name = str(uuid.uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
     queue = sqs.create_queue(QueueName=f"{function_name}_queue")
 
     conn = boto3.client("lambda", region_name="us-east-1")
     func1 = conn.create_function(
         FunctionName=function_name,
-        Runtime="python3.8",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -476,5 +652,8 @@ def test_delete_event_source_mapping():
     response = conn.delete_event_source_mapping(UUID=response["UUID"])
 
     assert response["State"] == "Deleting"
-    with pytest.raises(ClientError):
+    with pytest.raises(ClientError) as exc:
         conn.get_event_source_mapping(UUID=response["UUID"])
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "The resource you requested does not exist."
