@@ -4,10 +4,10 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_dms
+from moto import mock_aws
 
 
-@mock_dms
+@mock_aws
 def test_create_and_get_replication_task():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -40,7 +40,7 @@ def test_create_and_get_replication_task():
     assert isinstance(json.loads(task["ReplicationTaskSettings"]), dict)
 
 
-@mock_dms
+@mock_aws
 def test_create_existing_replication_task_throws_error():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -71,7 +71,7 @@ def test_create_existing_replication_task_throws_error():
     )
 
 
-@mock_dms
+@mock_aws
 def test_start_replication_task():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -94,7 +94,7 @@ def test_start_replication_task():
     assert tasks["ReplicationTasks"][0]["Status"] == "running"
 
 
-@mock_dms
+@mock_aws
 def test_start_replication_task_throws_resource_not_found_error():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -111,7 +111,7 @@ def test_start_replication_task_throws_resource_not_found_error():
     )
 
 
-@mock_dms
+@mock_aws
 def test_stop_replication_task_throws_invalid_state_error():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -133,7 +133,7 @@ def test_stop_replication_task_throws_invalid_state_error():
     assert ex.value.response["Error"]["Message"] == "Replication task is not running"
 
 
-@mock_dms
+@mock_aws
 def test_stop_replication_task_throws_resource_not_found_error():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -147,7 +147,7 @@ def test_stop_replication_task_throws_resource_not_found_error():
     )
 
 
-@mock_dms
+@mock_aws
 def test_stop_replication_task():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -171,7 +171,7 @@ def test_stop_replication_task():
     assert tasks["ReplicationTasks"][0]["Status"] == "stopped"
 
 
-@mock_dms
+@mock_aws
 def test_delete_replication_task():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -192,7 +192,7 @@ def test_delete_replication_task():
     assert len(tasks["ReplicationTasks"]) == 0
 
 
-@mock_dms
+@mock_aws
 def test_delete_replication_task_throws_resource_not_found_error():
     client = boto3.client("dms", region_name="us-east-1")
 
@@ -204,3 +204,84 @@ def test_delete_replication_task_throws_resource_not_found_error():
     assert (
         ex.value.response["Error"]["Message"] == "Replication task could not be found."
     )
+
+
+@mock_aws
+def test_create_replication_instance():
+    client = boto3.client("dms", region_name="us-east-1")
+
+    response = client.create_replication_instance(
+        ReplicationInstanceIdentifier="test-instance",
+        ReplicationInstanceClass="dms.t2.micro",
+        AllocatedStorage=50,
+        VpcSecurityGroupIds=["sg-12345"],
+        AvailabilityZone="us-east-1a",
+        ReplicationSubnetGroupIdentifier="default-subnet-group",
+        PreferredMaintenanceWindow="sun:06:00-sun:14:00",
+        MultiAZ=False,
+        EngineVersion="3.4.6",
+        AutoMinorVersionUpgrade=True,
+        Tags=[{"Key": "Name", "Value": "Test Instance"}],
+        PubliclyAccessible=True,
+        NetworkType="IPV4",
+    )
+
+    instance = response["ReplicationInstance"]
+    assert instance["ReplicationInstanceIdentifier"] == "test-instance"
+    assert instance["ReplicationInstanceClass"] == "dms.t2.micro"
+    assert instance["AllocatedStorage"] == 50
+    assert instance["AvailabilityZone"] == "us-east-1a"
+    assert instance["ReplicationInstanceStatus"] == "creating"
+    assert instance["MultiAZ"] is False
+    assert instance["EngineVersion"] == "3.4.6"
+    assert instance["AutoMinorVersionUpgrade"] is True
+    assert instance["PubliclyAccessible"] is True
+    assert instance["NetworkType"] == "IPV4"
+
+    arn = instance["ReplicationInstanceArn"]
+    assert arn.startswith("arn:aws:dms:us-east-1:")
+    assert ":rep:test-instance" in arn
+
+    response = client.describe_replication_instances(
+        Filters=[{"Name": "replication-instance-id", "Values": ["test-instance"]}]
+    )
+    assert len(response["ReplicationInstances"]) == 1
+    assert (
+        response["ReplicationInstances"][0]["ReplicationInstanceIdentifier"]
+        == "test-instance"
+    )
+
+
+@mock_aws
+def test_describe_replication_instances():
+    client = boto3.client("dms", region_name="us-east-1")
+
+    client.create_replication_instance(
+        ReplicationInstanceIdentifier="test-instance-1",
+        ReplicationInstanceClass="dms.t2.micro",
+        EngineVersion="3.4.5",
+    )
+
+    client.create_replication_instance(
+        ReplicationInstanceIdentifier="test-instance-2",
+        ReplicationInstanceClass="dms.t2.small",
+        EngineVersion="3.4.6",
+    )
+
+    response = client.describe_replication_instances()
+    instances = response["ReplicationInstances"]
+    assert len(instances) == 2
+
+    response = client.describe_replication_instances(
+        Filters=[{"Name": "replication-instance-class", "Values": ["dms.t2.micro"]}]
+    )
+    instances = response["ReplicationInstances"]
+    assert len(instances) == 1
+    assert instances[0]["ReplicationInstanceIdentifier"] == "test-instance-1"
+
+    response = client.describe_replication_instances(
+        Filters=[{"Name": "engine-version", "Values": ["3.4.6"]}]
+    )
+    instances = response["ReplicationInstances"]
+    assert len(instances) == 1
+    assert instances[0]["ReplicationInstanceIdentifier"] == "test-instance-2"
