@@ -3,15 +3,17 @@ import random
 import unittest
 import warnings
 from datetime import datetime, timezone
+from time import sleep
+from uuid import uuid4
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_logs, settings
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.core.utils import iso_8601_datetime_without_milliseconds
-from moto.events import mock_events
+from tests import allow_aws_request, aws_verified
 
 RULES = [
     {"Name": "test1", "ScheduleExpression": "rate(5 minutes)"},
@@ -83,7 +85,7 @@ def generate_environment(add_targets=True):
     return client
 
 
-@mock_events
+@mock_aws
 def test_put_rule():
     client = boto3.client("events", "us-west-2")
     assert len(client.list_rules()["Rules"]) == 0
@@ -105,7 +107,7 @@ def test_put_rule():
     assert rules[0]["State"] == "ENABLED"
 
 
-@mock_events
+@mock_aws
 def test_put_rule__where_event_bus_name_is_arn():
     client = boto3.client("events", "us-west-2")
     event_bus_name = "test-bus"
@@ -119,7 +121,7 @@ def test_put_rule__where_event_bus_name_is_arn():
     assert rule_arn == f"arn:aws:events:us-west-2:{ACCOUNT_ID}:rule/test-bus/my-event"
 
 
-@mock_events
+@mock_aws
 def test_put_rule_error_schedule_expression_custom_event_bus():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -145,7 +147,7 @@ def test_put_rule_error_schedule_expression_custom_event_bus():
     )
 
 
-@mock_events
+@mock_aws
 def test_list_rules():
     client = generate_environment()
     response = client.list_rules()
@@ -153,7 +155,7 @@ def test_list_rules():
     assert len(rules) == len(RULES)
 
 
-@mock_events
+@mock_aws
 def test_list_rules_with_token():
     client = generate_environment()
     response = client.list_rules()
@@ -172,7 +174,7 @@ def test_list_rules_with_token():
     assert len(rules) == 2
 
 
-@mock_events
+@mock_aws
 def test_list_rules_with_prefix_and_token():
     client = generate_environment()
     response = client.list_rules(NamePrefix="test")
@@ -191,7 +193,7 @@ def test_list_rules_with_prefix_and_token():
     assert len(rules) == 2
 
 
-@mock_events
+@mock_aws
 def test_describe_rule():
     rule_name = get_random_rule()["Name"]
     client = generate_environment()
@@ -201,7 +203,7 @@ def test_describe_rule():
     assert response["Arn"] == f"arn:aws:events:us-west-2:{ACCOUNT_ID}:rule/{rule_name}"
 
 
-@mock_events
+@mock_aws
 def test_describe_rule_with_event_bus_name():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -237,7 +239,7 @@ def test_describe_rule_with_event_bus_name():
     assert "ScheduleExpression" not in response
 
 
-@mock_events
+@mock_aws
 def test_enable_disable_rule():
     rule_name = get_random_rule()["Name"]
     client = generate_environment()
@@ -262,7 +264,7 @@ def test_enable_disable_rule():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_events
+@mock_aws
 def test_disable_unknown_rule():
     client = generate_environment()
 
@@ -272,7 +274,7 @@ def test_disable_unknown_rule():
     assert err["Message"] == "Rule unknown does not exist."
 
 
-@mock_events
+@mock_aws
 def test_list_rule_names_by_target():
     test_1_target = TARGETS["test-target-1"]
     test_2_target = TARGETS["test-target-2"]
@@ -289,7 +291,7 @@ def test_list_rule_names_by_target():
         assert rule in test_2_target["Rules"]
 
 
-@mock_events
+@mock_aws
 def test_list_rule_names_by_target_using_limit():
     test_1_target = TARGETS["test-target-1"]
     client = generate_environment()
@@ -305,7 +307,7 @@ def test_list_rule_names_by_target_using_limit():
     assert len(response["RuleNames"]) == 1
 
 
-@mock_events
+@mock_aws
 def test_delete_rule():
     client = generate_environment(add_targets=False)
 
@@ -314,7 +316,7 @@ def test_delete_rule():
     assert len(rules["Rules"]) == len(RULES) - 1
 
 
-@mock_events
+@mock_aws
 def test_delete_rule_with_targets():
     # given
     client = generate_environment()
@@ -333,7 +335,7 @@ def test_delete_rule_with_targets():
     )
 
 
-@mock_events
+@mock_aws
 def test_delete_unknown_rule():
     client = boto3.client("events", "us-west-1")
     resp = client.delete_rule(Name="unknown")
@@ -342,7 +344,7 @@ def test_delete_unknown_rule():
     assert resp["ResponseMetadata"]["HTTPStatusCode"] == 200
 
 
-@mock_events
+@mock_aws
 def test_list_targets_by_rule():
     rule_name = get_random_rule()["Name"]
     client = generate_environment()
@@ -356,7 +358,22 @@ def test_list_targets_by_rule():
     assert len(targets["Targets"]) == len(expected_targets)
 
 
-@mock_events
+@mock_aws
+def test_list_targets_by_rule_pagination():
+    rule_name = "test1"
+    client = generate_environment()
+    page1 = client.list_targets_by_rule(Rule=rule_name, Limit=1)
+    assert len(page1["Targets"]) == 1
+    assert "NextToken" in page1
+
+    page2 = client.list_targets_by_rule(Rule=rule_name, NextToken=page1["NextToken"])
+    assert len(page2["Targets"]) == 5
+
+    large_page = client.list_targets_by_rule(Rule=rule_name, Limit=4)
+    assert len(large_page["Targets"]) == 4
+
+
+@mock_aws
 def test_list_targets_by_rule_for_different_event_bus():
     client = generate_environment()
 
@@ -390,7 +407,7 @@ def test_list_targets_by_rule_for_different_event_bus():
     assert [t["Id"] for t in targets] == ["newtarget"]
 
 
-@mock_events
+@mock_aws
 def test_remove_targets():
     rule_name = get_random_rule()["Name"]
     client = generate_environment()
@@ -408,7 +425,7 @@ def test_remove_targets():
     assert targets_before - 1 == targets_after
 
 
-@mock_events
+@mock_aws
 def test_update_rule_with_targets():
     client = boto3.client("events", "us-west-2")
     client.put_rule(Name="test1", ScheduleExpression="rate(5 minutes)", EventPattern="")
@@ -435,7 +452,7 @@ def test_update_rule_with_targets():
     assert targets[0].get("Id") == "test-target-1"
 
 
-@mock_events
+@mock_aws
 def test_remove_targets_error_unknown_rule():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -455,7 +472,7 @@ def test_remove_targets_error_unknown_rule():
     )
 
 
-@mock_events
+@mock_aws
 def test_put_targets():
     client = boto3.client("events", "us-west-2")
     rule_name = "my-event"
@@ -484,7 +501,7 @@ def test_put_targets():
     assert targets[0]["Id"] == "test_id"
 
 
-@mock_events
+@mock_aws
 def test_put_targets_error_invalid_arn():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -516,7 +533,7 @@ def test_put_targets_error_invalid_arn():
     )
 
 
-@mock_events
+@mock_aws
 def test_put_targets_error_unknown_rule():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -538,7 +555,7 @@ def test_put_targets_error_unknown_rule():
     )
 
 
-@mock_events
+@mock_aws
 def test_put_targets_error_missing_parameter_sqs_fifo():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -566,7 +583,7 @@ def test_put_targets_error_missing_parameter_sqs_fifo():
     )
 
 
-@mock_events
+@mock_aws
 def test_permissions():
     client = boto3.client("events", "eu-central-1")
 
@@ -589,7 +606,7 @@ def test_permissions():
     assert resp_policy["Statement"][0]["Sid"] == "Account1"
 
 
-@mock_events
+@mock_aws
 def test_permission_policy():
     client = boto3.client("events", "eu-central-1")
 
@@ -613,7 +630,7 @@ def test_permission_policy():
     assert resp_policy["Statement"][0]["Sid"] == "asdf"
 
 
-@mock_events
+@mock_aws
 def test_put_permission_errors():
     client = boto3.client("events", "us-east-1")
     client.create_event_bus(Name="test-bus")
@@ -639,7 +656,7 @@ def test_put_permission_errors():
     assert err["Message"] == "Provided value in parameter 'action' is not supported."
 
 
-@mock_events
+@mock_aws
 def test_remove_permission_errors():
     client = boto3.client("events", "us-east-1")
     client.create_event_bus(Name="test-bus")
@@ -667,7 +684,7 @@ def test_remove_permission_errors():
     assert err["Message"] == "Statement with the provided id does not exist."
 
 
-@mock_events
+@mock_aws
 def test_put_events():
     client = boto3.client("events", "eu-central-1")
 
@@ -691,7 +708,7 @@ def test_put_events():
         assert any(["EventDetail should be of type dict" in msg for msg in messages])
 
 
-@mock_events
+@mock_aws
 def test_put_events_error_too_many_entries():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -720,58 +737,35 @@ def test_put_events_error_too_many_entries():
     )
 
 
-@mock_events
-def test_put_events_error_missing_argument_source():
+@mock_aws
+@pytest.mark.parametrize(
+    "argument,entries",
+    [
+        ("Source", [{}]),
+        ("Source", [{"Source": ""}]),
+        ("DetailType", [{"Source": "source"}]),
+        ("DetailType", [{"Source": "source", "DetailType": ""}]),
+        ("Detail", [{"Source": "source", "DetailType": "type"}]),
+        ("Detail", [{"Source": "source", "DetailType": "typee", "Detail": ""}]),
+    ],
+)
+def test_put_events_error_missing_or_empty_required_argument(argument, entries):
     # given
     client = boto3.client("events", "eu-central-1")
 
     # when
-    response = client.put_events(Entries=[{}])
+    response = client.put_events(Entries=entries)
 
     # then
     assert response["FailedEntryCount"] == 1
     assert len(response["Entries"]) == 1
     assert response["Entries"][0] == {
         "ErrorCode": "InvalidArgument",
-        "ErrorMessage": "Parameter Source is not valid. Reason: Source is a required argument.",
+        "ErrorMessage": f"Parameter {argument} is not valid. Reason: {argument} is a required argument.",
     }
 
 
-@mock_events
-def test_put_events_error_missing_argument_detail_type():
-    # given
-    client = boto3.client("events", "eu-central-1")
-
-    # when
-    response = client.put_events(Entries=[{"Source": "source"}])
-
-    # then
-    assert response["FailedEntryCount"] == 1
-    assert len(response["Entries"]) == 1
-    assert response["Entries"][0] == {
-        "ErrorCode": "InvalidArgument",
-        "ErrorMessage": "Parameter DetailType is not valid. Reason: DetailType is a required argument.",
-    }
-
-
-@mock_events
-def test_put_events_error_missing_argument_detail():
-    # given
-    client = boto3.client("events", "eu-central-1")
-
-    # when
-    response = client.put_events(Entries=[{"DetailType": "type", "Source": "source"}])
-
-    # then
-    assert response["FailedEntryCount"] == 1
-    assert len(response["Entries"]) == 1
-    assert response["Entries"][0] == {
-        "ErrorCode": "InvalidArgument",
-        "ErrorMessage": "Parameter Detail is not valid. Reason: Detail is a required argument.",
-    }
-
-
-@mock_events
+@mock_aws
 def test_put_events_error_invalid_json_detail():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -790,7 +784,7 @@ def test_put_events_error_invalid_json_detail():
     }
 
 
-@mock_events
+@mock_aws
 def test_put_events_with_mixed_entries():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -812,7 +806,7 @@ def test_put_events_with_mixed_entries():
     assert len([entry for entry in response["Entries"] if "ErrorCode" in entry]) == 2
 
 
-@mock_events
+@mock_aws
 def test_create_event_bus():
     client = boto3.client("events", "us-east-1")
     response = client.create_event_bus(Name="test-bus")
@@ -823,7 +817,7 @@ def test_create_event_bus():
     )
 
 
-@mock_events
+@mock_aws
 def test_create_event_bus_errors():
     client = boto3.client("events", "us-east-1")
     client.create_event_bus(Name="test-bus")
@@ -854,7 +848,7 @@ def test_create_event_bus_errors():
     assert err["Message"] == "Event source aws.partner/test/test-bus does not exist."
 
 
-@mock_events
+@mock_aws
 def test_describe_event_bus():
     client = boto3.client("events", "us-east-1")
 
@@ -892,7 +886,7 @@ def test_describe_event_bus():
     }
 
 
-@mock_events
+@mock_aws
 def test_describe_event_bus_errors():
     client = boto3.client("events", "us-east-1")
 
@@ -902,7 +896,7 @@ def test_describe_event_bus_errors():
     assert err["Message"] == "Event bus non-existing does not exist."
 
 
-@mock_events
+@mock_aws
 def test_list_event_buses():
     client = boto3.client("events", "us-east-1")
     client.create_event_bus(Name="test-bus-1")
@@ -951,7 +945,7 @@ def test_list_event_buses():
     ]
 
 
-@mock_events
+@mock_aws
 def test_delete_event_bus():
     client = boto3.client("events", "us-east-1")
     client.create_event_bus(Name="test-bus")
@@ -974,7 +968,7 @@ def test_delete_event_bus():
     client.delete_event_bus(Name="non-existing")
 
 
-@mock_events
+@mock_aws
 def test_delete_event_bus_errors():
     client = boto3.client("events", "us-east-1")
 
@@ -984,7 +978,7 @@ def test_delete_event_bus_errors():
     assert err["Message"] == "Cannot delete event bus default."
 
 
-@mock_events
+@mock_aws
 def test_create_rule_with_tags():
     client = generate_environment()
     rule_name = "test2"
@@ -994,7 +988,7 @@ def test_create_rule_with_tags():
     assert actual == [{"Key": "tagk1", "Value": "tagv1"}]
 
 
-@mock_events
+@mock_aws
 def test_delete_rule_with_tags():
     client = generate_environment(add_targets=False)
     rule_name = "test2"
@@ -1012,7 +1006,7 @@ def test_delete_rule_with_tags():
     assert err["Message"] == "Rule test2 does not exist."
 
 
-@mock_events
+@mock_aws
 def test_rule_tagging_happy():
     client = generate_environment()
     rule_name = "test1"
@@ -1036,7 +1030,7 @@ def test_rule_tagging_happy():
     assert expected == actual
 
 
-@mock_events
+@mock_aws
 def test_tag_resource_error_unknown_arn():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1059,7 +1053,7 @@ def test_tag_resource_error_unknown_arn():
     )
 
 
-@mock_events
+@mock_aws
 def test_untag_resource_error_unknown_arn():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1082,7 +1076,7 @@ def test_untag_resource_error_unknown_arn():
     )
 
 
-@mock_events
+@mock_aws
 def test_list_tags_for_resource_error_unknown_arn():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1104,7 +1098,7 @@ def test_list_tags_for_resource_error_unknown_arn():
     )
 
 
-@mock_events
+@mock_aws
 def test_create_archive():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1143,7 +1137,7 @@ def test_create_archive():
     assert "ScheduleExpression" not in response
 
 
-@mock_events
+@mock_aws
 def test_create_archive_custom_event_bus():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1171,7 +1165,7 @@ def test_create_archive_custom_event_bus():
     assert response["State"] == "ENABLED"
 
 
-@mock_events
+@mock_aws
 def test_create_archive_error_long_name():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1197,7 +1191,7 @@ def test_create_archive_error_long_name():
     )
 
 
-@mock_events
+@mock_aws
 def test_create_archive_error_invalid_event_pattern():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1223,7 +1217,7 @@ def test_create_archive_error_invalid_event_pattern():
     )
 
 
-@mock_events
+@mock_aws
 def test_create_archive_error_invalid_event_pattern_not_an_array():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1256,7 +1250,7 @@ def test_create_archive_error_invalid_event_pattern_not_an_array():
     )
 
 
-@mock_events
+@mock_aws
 def test_create_archive_error_unknown_event_bus():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1281,7 +1275,7 @@ def test_create_archive_error_unknown_event_bus():
     )
 
 
-@mock_events
+@mock_aws
 def test_create_archive_error_duplicate():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1301,7 +1295,7 @@ def test_create_archive_error_duplicate():
     assert ex.response["Error"]["Message"] == "Archive test-archive already exists."
 
 
-@mock_events
+@mock_aws
 def test_describe_archive():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1334,7 +1328,7 @@ def test_describe_archive():
     assert response["State"] == "ENABLED"
 
 
-@mock_events
+@mock_aws
 def test_describe_archive_error_unknown_archive():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1352,7 +1346,7 @@ def test_describe_archive_error_unknown_archive():
     assert ex.response["Error"]["Message"] == f"Archive {name} does not exist."
 
 
-@mock_events
+@mock_aws
 def test_list_archives():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1385,7 +1379,7 @@ def test_list_archives():
     assert "EventPattern" not in archive
 
 
-@mock_events
+@mock_aws
 def test_list_archives_with_name_prefix():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1401,7 +1395,7 @@ def test_list_archives_with_name_prefix():
     assert archives[0]["ArchiveName"] == "test-archive"
 
 
-@mock_events
+@mock_aws
 def test_list_archives_with_source_arn():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1418,7 +1412,7 @@ def test_list_archives_with_source_arn():
     assert archives[0]["ArchiveName"] == "test"
 
 
-@mock_events
+@mock_aws
 def test_list_archives_with_state():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1433,7 +1427,7 @@ def test_list_archives_with_state():
     assert len(archives) == 0
 
 
-@mock_events
+@mock_aws
 def test_list_archives_error_multiple_filters():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1453,7 +1447,7 @@ def test_list_archives_error_multiple_filters():
     )
 
 
-@mock_events
+@mock_aws
 def test_list_archives_error_invalid_state():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1473,7 +1467,7 @@ def test_list_archives_error_invalid_state():
     )
 
 
-@mock_events
+@mock_aws
 def test_update_archive():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1511,7 +1505,7 @@ def test_update_archive():
     assert response["State"] == "ENABLED"
 
 
-@mock_events
+@mock_aws
 def test_update_archive_error_invalid_event_pattern():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1536,7 +1530,7 @@ def test_update_archive_error_invalid_event_pattern():
     )
 
 
-@mock_events
+@mock_aws
 def test_update_archive_error_unknown_archive():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1554,7 +1548,7 @@ def test_update_archive_error_unknown_archive():
     assert ex.response["Error"]["Message"] == f"Archive {name} does not exist."
 
 
-@mock_events
+@mock_aws
 def test_delete_archive():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1572,7 +1566,7 @@ def test_delete_archive():
     assert len(response) == 0
 
 
-@mock_events
+@mock_aws
 def test_delete_archive_error_unknown_archive():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1590,14 +1584,17 @@ def test_delete_archive_error_unknown_archive():
     assert ex.response["Error"]["Message"] == f"Archive {name} does not exist."
 
 
-@mock_events
+@aws_verified
+@pytest.mark.aws_verified
 def test_archive_actual_events():
     # given
+    sts = boto3.client("sts", "us-east-1")
+    account_id = sts.get_caller_identity()["Account"]
     client = boto3.client("events", "eu-central-1")
     name = "test-archive"
     name_2 = "test-archive-no-match"
     name_3 = "test-archive-matches"
-    event_bus_arn = f"arn:aws:events:eu-central-1:{ACCOUNT_ID}:event-bus/default"
+    event_bus_arn = f"arn:aws:events:eu-central-1:{account_id}:event-bus/default"
     event = {
         "Source": "source",
         "DetailType": "type",
@@ -1615,27 +1612,75 @@ def test_archive_actual_events():
         EventPattern=json.dumps({"detail-type": ["type"], "source": ["source"]}),
     )
 
+    # then
+    rules = client.list_rules()["Rules"]
+    assert len(rules) >= 3
+    for rule in rules:
+        assert rule["Name"] in [
+            f"Events-Archive-{name}",
+            f"Events-Archive-{name_2}",
+            f"Events-Archive-{name_3}",
+        ]
+        assert rule["ManagedBy"] == "prod.vhs.events.aws.internal"
+        if rule["Name"] == f"Events-Archive-{name}":
+            assert json.loads(rule["EventPattern"]) == {
+                "replay-name": [{"exists": False}]
+            }
+        if rule["Name"] == f"Events-Archive-{name_2}":
+            assert json.loads(rule["EventPattern"]) == {
+                "detail-type": ["type"],
+                "replay-name": [{"exists": False}],
+                "source": ["test"],
+            }
+        if rule["Name"] == f"Events-Archive-{name_3}":
+            assert json.loads(rule["EventPattern"]) == {
+                "detail-type": ["type"],
+                "replay-name": [{"exists": False}],
+                "source": ["source"],
+            }
+
+        targets = client.list_targets_by_rule(Rule=rule["Name"])["Targets"]
+        assert len(targets) == 1
+        assert targets[0]["Arn"] == "arn:aws:events:eu-central-1:::"
+
+        transformer = targets[0]["InputTransformer"]
+        assert transformer["InputPathsMap"] == {}
+
+        template = transformer["InputTemplate"]
+        assert '"archive-arn"' in template
+        assert '"event": <aws.events.event.json>' in template
+        assert '"ingestion-time": <aws.events.event.ingestion-time>' in template
+
     # when
     response = client.put_events(Entries=[event])
-
-    # then
     assert response["FailedEntryCount"] == 0
     assert len(response["Entries"]) == 1
 
-    response = client.describe_archive(ArchiveName=name)
-    assert response["EventCount"] == 1
-    assert response["SizeBytes"] > 0
+    # then
+    if not allow_aws_request():
+        # AWS doesn't (immediately) update the EventCount
+        # Only test this against Moto
+        response = client.describe_archive(ArchiveName=name)
+        assert response["EventCount"] == 1
+        assert response["SizeBytes"] > 0
 
-    response = client.describe_archive(ArchiveName=name_2)
-    assert response["EventCount"] == 0
-    assert response["SizeBytes"] == 0
+        response = client.describe_archive(ArchiveName=name_2)
+        assert response["EventCount"] == 0
+        assert response["SizeBytes"] == 0
 
-    response = client.describe_archive(ArchiveName=name_3)
-    assert response["EventCount"] == 1
-    assert response["SizeBytes"] > 0
+        response = client.describe_archive(ArchiveName=name_3)
+        assert response["EventCount"] == 1
+        assert response["SizeBytes"] > 0
+
+    client.delete_archive(ArchiveName=name)
+    client.delete_archive(ArchiveName=name_2)
+    client.delete_archive(ArchiveName=name_3)
+
+    rules = client.list_rules()["Rules"]
+    assert rules == []
 
 
-@mock_events
+@mock_aws
 def test_archive_event_with_bus_arn():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1661,7 +1706,7 @@ def test_archive_event_with_bus_arn():
     assert response["SizeBytes"] > 0
 
 
-@mock_events
+@mock_aws
 def test_start_replay():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1689,7 +1734,7 @@ def test_start_replay():
     assert response["State"] == "STARTING"
 
 
-@mock_events
+@mock_aws
 def test_start_replay_error_unknown_event_bus():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1717,7 +1762,7 @@ def test_start_replay_error_unknown_event_bus():
     )
 
 
-@mock_events
+@mock_aws
 def test_start_replay_error_invalid_event_bus_arn():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1745,7 +1790,7 @@ def test_start_replay_error_invalid_event_bus_arn():
     )
 
 
-@mock_events
+@mock_aws
 def test_start_replay_error_unknown_archive():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1774,7 +1819,7 @@ def test_start_replay_error_unknown_archive():
     )
 
 
-@mock_events
+@mock_aws
 def test_start_replay_error_cross_event_bus():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1805,7 +1850,7 @@ def test_start_replay_error_cross_event_bus():
     )
 
 
-@mock_events
+@mock_aws
 def test_start_replay_error_invalid_end_time():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1835,7 +1880,7 @@ def test_start_replay_error_invalid_end_time():
     )
 
 
-@mock_events
+@mock_aws
 def test_start_replay_error_duplicate():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1870,7 +1915,7 @@ def test_start_replay_error_duplicate():
     assert ex.response["Error"]["Message"] == f"Replay {name} already exists."
 
 
-@mock_events
+@mock_aws
 def test_describe_replay():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1907,7 +1952,7 @@ def test_describe_replay():
     assert response["State"] == "COMPLETED"
 
 
-@mock_events
+@mock_aws
 def test_describe_replay_error_unknown_replay():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1925,7 +1970,7 @@ def test_describe_replay_error_unknown_replay():
     assert ex.response["Error"]["Message"] == f"Replay {name} does not exist."
 
 
-@mock_events
+@mock_aws
 def test_list_replays():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1958,7 +2003,7 @@ def test_list_replays():
     assert replay["State"] == "COMPLETED"
 
 
-@mock_events
+@mock_aws
 def test_list_replays_with_name_prefix():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -1989,7 +2034,7 @@ def test_list_replays_with_name_prefix():
     assert replays[0]["ReplayName"] == "test-replay"
 
 
-@mock_events
+@mock_aws
 def test_list_replays_with_source_arn():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -2019,7 +2064,7 @@ def test_list_replays_with_source_arn():
     assert len(replays) == 2
 
 
-@mock_events
+@mock_aws
 def test_list_replays_with_state():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -2049,7 +2094,7 @@ def test_list_replays_with_state():
     assert len(replays) == 0
 
 
-@mock_events
+@mock_aws
 def test_list_replays_error_multiple_filters():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -2069,7 +2114,7 @@ def test_list_replays_error_multiple_filters():
     )
 
 
-@mock_events
+@mock_aws
 def test_list_replays_error_invalid_state():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -2089,7 +2134,7 @@ def test_list_replays_error_invalid_state():
     )
 
 
-@mock_events
+@mock_aws
 def test_cancel_replay():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -2121,7 +2166,7 @@ def test_cancel_replay():
     assert response["State"] == "CANCELLED"
 
 
-@mock_events
+@mock_aws
 def test_cancel_replay_error_unknown_replay():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -2139,7 +2184,7 @@ def test_cancel_replay_error_unknown_replay():
     assert ex.response["Error"]["Message"] == f"Replay {name} does not exist."
 
 
-@mock_events
+@mock_aws
 def test_cancel_replay_error_illegal_state():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -2173,8 +2218,7 @@ def test_cancel_replay_error_illegal_state():
     )
 
 
-@mock_events
-@mock_logs
+@mock_aws
 def test_start_replay_send_to_log_group():
     # given
     client = boto3.client("events", "eu-central-1")
@@ -2245,7 +2289,7 @@ def test_start_replay_send_to_log_group():
     assert event_replay["replay-name"] == "test-replay"
 
 
-@mock_events
+@mock_aws
 def test_create_and_list_connections():
     client = boto3.client("events", "eu-central-1")
 
@@ -2273,9 +2317,10 @@ def test_create_and_list_connections():
         f"arn:aws:events:eu-central-1:{ACCOUNT_ID}:connection/test/"
         in response["Connections"][0]["ConnectionArn"]
     )
+    assert response["Connections"][0]["Name"] == "test"
 
 
-@mock_events
+@mock_aws
 def test_create_and_describe_connection():
     client = boto3.client("events", "eu-central-1")
 
@@ -2294,10 +2339,11 @@ def test_create_and_describe_connection():
     assert description["Description"] == "test description"
     assert description["AuthorizationType"] == "API_KEY"
     assert description["ConnectionState"] == "AUTHORIZED"
+    assert description["SecretArn"] is not None
     assert "CreationTime" in description
 
 
-@mock_events
+@mock_aws
 def test_create_and_update_connection():
     client = boto3.client("events", "eu-central-1")
 
@@ -2321,7 +2367,97 @@ def test_create_and_update_connection():
     assert "CreationTime" in description
 
 
-@mock_events
+@aws_verified
+@pytest.mark.aws_verified
+@pytest.mark.parametrize(
+    "auth_type,auth_parameters",
+    [
+        (
+            "API_KEY",
+            {"ApiKeyAuthParameters": {"ApiKeyName": "test", "ApiKeyValue": "test"}},
+        ),
+        ("BASIC", {"BasicAuthParameters": {"Username": "un", "Password": "pw"}}),
+    ],
+    ids=["auth_params", "basic_auth_params"],
+)
+@pytest.mark.parametrize(
+    "with_headers", [True, False], ids=["with_headers", "without_headers"]
+)
+def test_kms_key_is_created(auth_type, auth_parameters, with_headers):
+    client = boto3.client("events", "us-east-1")
+    secrets = boto3.client("secretsmanager", "us-east-1")
+    sts = boto3.client("sts", "us-east-1")
+
+    name = f"event_{str(uuid4())[0:6]}"
+    account_id = sts.get_caller_identity()["Account"]
+    connection_deleted = False
+    if with_headers:
+        auth_parameters["InvocationHttpParameters"] = {
+            "HeaderParameters": [
+                {"Key": "k1", "Value": "v1", "IsValueSecret": True},
+                {"Key": "k2", "Value": "v2", "IsValueSecret": False},
+            ]
+        }
+    else:
+        auth_parameters.pop("InvocationHttpParameters", None)
+
+    client.create_connection(
+        Name=name,
+        AuthorizationType=auth_type,
+        AuthParameters=auth_parameters,
+    )
+    try:
+        description = client.describe_connection(Name=name)
+        secret_arn = description["SecretArn"]
+        assert secret_arn.startswith(
+            f"arn:aws:secretsmanager:us-east-1:{account_id}:secret:events!connection/{name}/"
+        )
+
+        secret = secrets.describe_secret(SecretId=secret_arn)
+        assert secret["Name"].startswith(f"events!connection/{name}/")
+        assert secret["Tags"] == [
+            {"Key": "aws:secretsmanager:owningService", "Value": "events"}
+        ]
+        assert secret["OwningService"] == "events"
+
+        if auth_type == "BASIC":
+            expected_secret = {"username": "un", "password": "pw"}
+        else:
+            expected_secret = {"api_key_name": "test", "api_key_value": "test"}
+        if with_headers:
+            expected_secret["invocation_http_parameters"] = {
+                "header_parameters": [
+                    {"key": "k1", "value": "v1", "is_value_secret": True},
+                    {"key": "k2", "value": "v2", "is_value_secret": False},
+                ]
+            }
+
+        secret_value = secrets.get_secret_value(SecretId=secret_arn)
+        assert json.loads(secret_value["SecretString"]) == expected_secret
+
+        client.delete_connection(Name=name)
+        connection_deleted = True
+
+        secret_deleted = False
+        attempts = 0
+        while not secret_deleted and attempts < 5:
+            try:
+                attempts += 1
+                secrets.describe_secret(SecretId=secret_arn)
+                sleep(1)
+            except ClientError as e:
+                secret_deleted = (
+                    e.response["Error"]["Code"] == "ResourceNotFoundException"
+                )
+
+        if not secret_deleted:
+            assert False, f"Should have automatically deleted secret {secret_arn}"
+    finally:
+        if not connection_deleted:
+            client.delete_connection(Name=name)
+
+
+@mock_aws
 def test_update_unknown_connection():
     client = boto3.client("events", "eu-north-1")
 
@@ -2331,7 +2467,7 @@ def test_update_unknown_connection():
     assert err["Message"] == "Connection 'unknown' does not exist."
 
 
-@mock_events
+@mock_aws
 def test_delete_connection():
     client = boto3.client("events", "eu-central-1")
 
@@ -2356,7 +2492,7 @@ def test_delete_connection():
     assert len(conns) == 0
 
 
-@mock_events
+@mock_aws
 def test_create_and_list_api_destinations():
     client = boto3.client("events", "eu-central-1")
 
@@ -2411,7 +2547,7 @@ def test_create_and_list_api_destinations():
         ("HttpMethod", "GET", "PATCH"),
     ],
 )
-@mock_events
+@mock_aws
 def test_create_and_update_api_destination(key, initial_value, updated_value):
     client = boto3.client("events", "eu-central-1")
 
@@ -2443,7 +2579,7 @@ def test_create_and_update_api_destination(key, initial_value, updated_value):
     assert destination[key] == updated_value
 
 
-@mock_events
+@mock_aws
 def test_delete_api_destination():
     client = boto3.client("events", "eu-central-1")
 
@@ -2471,7 +2607,7 @@ def test_delete_api_destination():
     assert len(client.list_api_destinations()["ApiDestinations"]) == 0
 
 
-@mock_events
+@mock_aws
 def test_describe_unknown_api_destination():
     client = boto3.client("events", "eu-central-1")
 
@@ -2481,7 +2617,7 @@ def test_describe_unknown_api_destination():
     assert err["Message"] == "An api-destination 'unknown' does not exist."
 
 
-@mock_events
+@mock_aws
 def test_delete_unknown_api_destination():
     client = boto3.client("events", "eu-central-1")
 
@@ -2494,7 +2630,7 @@ def test_delete_unknown_api_destination():
 # Scenarios for describe_connection
 # Scenario 01: Success
 # Scenario 02: Failure - Connection not present
-@mock_events
+@mock_aws
 def test_describe_connection_success():
     # Given
     conn_name = "test_conn_name"
@@ -2523,7 +2659,7 @@ def test_describe_connection_success():
     assert response["AuthParameters"] == expected_auth_param
 
 
-@mock_events
+@mock_aws
 def test_describe_connection_not_present():
     conn_name = "test_conn_name"
 
@@ -2539,7 +2675,7 @@ def test_describe_connection_not_present():
 # Scenario 02: Failure - Connection not present
 
 
-@mock_events
+@mock_aws
 def test_delete_connection_success():
     # Given
     conn_name = "test_conn_name"
@@ -2569,7 +2705,7 @@ def test_delete_connection_success():
         _ = client.describe_connection(Name=conn_name)
 
 
-@mock_events
+@mock_aws
 def test_delete_connection_not_present():
     conn_name = "test_conn_name"
 
