@@ -446,6 +446,79 @@ def test_get_tag_values_ec2():
     assert "MY_VALUE4" in resp["TagValues"]
 
 
+@mock_aws
+def test_get_tag_values_event_bus():
+    client = boto3.client("events", "us-east-1")
+    client.create_event_bus(Name="test-bus1")
+    event_bus_2 = client.create_event_bus(
+        Name="test-bus2", Tags=[{"Key": "Test", "Value": "Test2"}]
+    )
+    event_bus_3 = client.create_event_bus(Name="test-bus3")
+    client.tag_resource(
+        ResourceARN=event_bus_3["EventBusArn"], Tags=[{"Key": "Test", "Value": "Added"}]
+    )
+
+    rtapi = boto3.client("resourcegroupstaggingapi", "us-east-1")
+    resp = rtapi.get_resources(ResourceTypeFilters=["events:event-bus"])
+    assert len(resp["ResourceTagMappingList"]) == 2
+    assert event_bus_2["EventBusArn"] in [
+        x["ResourceARN"] for x in resp["ResourceTagMappingList"]
+    ]
+    assert event_bus_3["EventBusArn"] in [
+        x["ResourceARN"] for x in resp["ResourceTagMappingList"]
+    ]
+
+
+@mock_aws
+def test_get_tag_values_cloudfront():
+    client = boto3.client("cloudfront", "us-east-1")
+    for i in range(1, 3):
+        caller_reference = f"distribution{i}"
+        origin_id = f"origin{i}"
+
+        client.create_distribution_with_tags(
+            DistributionConfigWithTags={
+                "DistributionConfig": {
+                    "CallerReference": caller_reference,
+                    "Origins": {
+                        "Quantity": 1,
+                        "Items": [
+                            {
+                                "Id": origin_id,
+                                "DomainName": "example-bucket.s3.amazonaws.com",
+                                "S3OriginConfig": {"OriginAccessIdentity": ""},
+                            }
+                        ],
+                    },
+                    "DefaultCacheBehavior": {
+                        "TargetOriginId": origin_id,
+                        "ViewerProtocolPolicy": "allow-all",
+                        "TrustedSigners": {"Enabled": False, "Quantity": 0},
+                        "ForwardedValues": {
+                            "QueryString": False,
+                            "Cookies": {"Forward": "none"},
+                        },
+                        "MinTTL": 0,
+                    },
+                    "Comment": f"Sample distribution {i}",
+                    "Enabled": True,
+                },
+                "Tags": {"Items": [{"Key": "Test", "Value": f"Test{i}"}]},
+            }
+        )
+    rtapi = boto3.client("resourcegroupstaggingapi", "us-east-1")
+
+    # Test tag filtering
+    resp = rtapi.get_resources(
+        ResourceTypeFilters=["cloudfront"],
+        TagFilters=[{"Key": "Test", "Values": ["Test1"]}],
+    )
+    assert len(resp["ResourceTagMappingList"]) == 1
+    assert {"Key": "Test", "Value": "Test1"} in resp["ResourceTagMappingList"][0][
+        "Tags"
+    ]
+
+
 @mock_aws
 def test_get_many_resources():
     elbv2 = boto3.client("elbv2", region_name="us-east-1")
