@@ -1,13 +1,16 @@
+import uuid
+
 import boto3
 import botocore
 import pytest
 import requests
 from botocore.exceptions import ClientError
 
-from moto import mock_ec2, mock_route53, settings
+from moto import mock_aws, settings
+from moto.route53.models import HostedZoneIdentifier
 
 
-@mock_route53
+@mock_aws
 def test_create_hosted_zone():
     conn = boto3.client("route53", region_name="us-east-1")
     response = conn.create_hosted_zone(
@@ -31,7 +34,7 @@ def test_create_hosted_zone():
         assert "<Name>testdns.aws.com.</Name>" in requests.get(location).text
 
 
-@mock_route53
+@mock_aws
 def test_get_hosted_zone():
     conn = boto3.client("route53", region_name="us-east-1")
     name = "testdns.aws.com."
@@ -44,7 +47,7 @@ def test_get_hosted_zone():
     assert res["HostedZone"]["CallerReference"] == caller_ref
 
 
-@mock_route53
+@mock_aws
 def test_list_hosted_zones():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -65,7 +68,7 @@ def test_list_hosted_zones():
     assert zone2 in res
 
 
-@mock_route53
+@mock_aws
 def test_delete_hosted_zone():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -80,7 +83,7 @@ def test_delete_hosted_zone():
     assert len(res) == 1
 
 
-@mock_route53
+@mock_aws
 def test_delete_hosted_zone_with_change_sets():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -114,14 +117,14 @@ def test_delete_hosted_zone_with_change_sets():
     )
 
 
-@mock_route53
+@mock_aws
 def test_get_hosted_zone_count_no_zones():
     conn = boto3.client("route53", region_name="us-east-1")
     zone_count = conn.get_hosted_zone_count()
     assert zone_count["HostedZoneCount"] == 0
 
 
-@mock_route53
+@mock_aws
 def test_get_hosted_zone_count_one_zone():
     conn = boto3.client("route53", region_name="us-east-1")
     zone = "a"
@@ -135,7 +138,7 @@ def test_get_hosted_zone_count_one_zone():
     assert zone_count["HostedZoneCount"] == 1
 
 
-@mock_route53
+@mock_aws
 def test_get_hosted_zone_count_many_zones():
     conn = boto3.client("route53", region_name="us-east-1")
     zones = {}
@@ -158,7 +161,7 @@ def test_get_hosted_zone_count_many_zones():
     assert zone_count["HostedZoneCount"] == len(zone_indexes)
 
 
-@mock_route53
+@mock_aws
 def test_get_unknown_hosted_zone():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -170,7 +173,7 @@ def test_get_unknown_hosted_zone():
     assert err["Message"] == "No hosted zone found with ID: unknown"
 
 
-@mock_route53
+@mock_aws
 def test_update_hosted_zone_comment():
     conn = boto3.client("route53", region_name="us-east-1")
     response = conn.create_hosted_zone(
@@ -184,7 +187,7 @@ def test_update_hosted_zone_comment():
     assert resp["Config"]["Comment"] == "yolo"
 
 
-@mock_route53
+@mock_aws
 def test_list_resource_record_set_unknown_zone():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -196,7 +199,7 @@ def test_list_resource_record_set_unknown_zone():
     assert err["Message"] == "No hosted zone found with ID: abcd"
 
 
-@mock_route53
+@mock_aws
 def test_list_resource_record_set_unknown_type():
     conn = boto3.client("route53", region_name="us-east-1")
     zone = conn.create_hosted_zone(
@@ -211,7 +214,68 @@ def test_list_resource_record_set_unknown_type():
     assert err["Message"] == "Bad Request"
 
 
-@mock_route53
+@mock_aws
+@pytest.mark.parametrize("invalid_char", [" ", "\t"])
+def test_list_resource_record_set_invalid_start_record_name(invalid_char):
+    conn = boto3.client("route53", region_name="us-east-1")
+
+    zone_name = f"{str(uuid.uuid4())[0:6]}.getmoto.com."
+    record_name = f"i{invalid_char}d.e.com."
+    zone = conn.create_hosted_zone(
+        Name=zone_name, CallerReference=f"creation of {zone_name}"
+    )["HostedZone"]
+
+    with pytest.raises(ClientError) as ex:
+        conn.list_resource_record_sets(
+            HostedZoneId=zone["Id"], StartRecordName=record_name
+        )
+
+    err = ex.value.response["Error"]
+    assert err["Code"] == "InvalidInput"
+    assert (
+        err["Message"]
+        == f"FATAL problem: UnsupportedCharacter (Value contains unsupported characters) encountered with '{invalid_char}'"
+    )
+
+    with pytest.raises(ClientError) as exc:
+        conn.change_resource_record_sets(
+            HostedZoneId=zone["Id"],
+            ChangeBatch={
+                "Changes": [
+                    {
+                        "Action": "CREATE",
+                        "ResourceRecordSet": {"Name": record_name, "Type": "TXT"},
+                    }
+                ]
+            },
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidChangeBatch"
+    assert (
+        err["Message"]
+        == f"FATAL problem: UnsupportedCharacter (Value contains unsupported characters) encountered with '{invalid_char}'"
+    )
+
+
+@mock_aws
+@pytest.mark.parametrize("valid_char", ["*", ".", "\\t", "\\ ", "国", "}", "\\ç"])
+def test_list_resource_record_set_valid_characters(valid_char):
+    """
+    Validation that we can use odd characters as part of the domain name
+    Moto does not have parity in domain name validation, but at least we are not _too_ strict
+    """
+    conn = boto3.client("route53", region_name="us-east-1")
+
+    zone_name = f"{str(uuid.uuid4())[0:6]}.getmoto.com."
+    record_name = f"i{valid_char}d.e.com."
+    zone = conn.create_hosted_zone(
+        Name=zone_name, CallerReference=f"creation of {zone_name}"
+    )["HostedZone"]
+
+    conn.list_resource_record_sets(HostedZoneId=zone["Id"], StartRecordName=record_name)
+
+
+@mock_aws
 def test_use_health_check_in_resource_record_set():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -257,7 +321,7 @@ def test_use_health_check_in_resource_record_set():
     assert record_sets[2]["HealthCheckId"] == check_id
 
 
-@mock_route53
+@mock_aws
 def test_hosted_zone_comment_preserved():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -275,7 +339,7 @@ def test_hosted_zone_comment_preserved():
     assert hosted_zones["HostedZones"][0]["Config"]["Comment"] == "test comment"
 
 
-@mock_route53
+@mock_aws
 def test_deleting_weighted_route():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -332,7 +396,7 @@ def test_deleting_weighted_route():
     assert cnames[-1]["SetIdentifier"] == "success-test-bar"
 
 
-@mock_route53
+@mock_aws
 def test_deleting_latency_route():
     conn = boto3.client("route53", region_name="us-east-1")
 
@@ -399,7 +463,7 @@ def test_deleting_latency_route():
     assert cnames[-1]["Region"] == "us-west-1"
 
 
-@mock_route53
+@mock_aws
 def test_list_or_change_tags_for_resource_request():
     conn = boto3.client("route53", region_name="us-east-1")
     health_check = conn.create_health_check(
@@ -487,8 +551,136 @@ def test_list_or_change_tags_for_resource_request():
     assert response["ResourceTagSet"]["Tags"] == []
 
 
-@mock_ec2
-@mock_route53
+@mock_aws
+def test_list_tags_for_resources():
+    conn = boto3.client("route53", region_name="us-east-1")
+    # Create two hosted zones
+    zone1 = conn.create_hosted_zone(
+        Name="testdns1.aws.com", CallerReference=str(hash("foo"))
+    )
+    zone1_id = zone1["HostedZone"]["Id"]
+    zone2 = conn.create_hosted_zone(
+        Name="testdns2.aws.com", CallerReference=str(hash("bar"))
+    )
+    zone2_id = zone2["HostedZone"]["Id"]
+
+    # Create two healthchecks
+    health_check1 = conn.create_health_check(
+        CallerReference="foo",
+        HealthCheckConfig={
+            "IPAddress": "192.0.2.44",
+            "Port": 123,
+            "Type": "HTTP",
+            "ResourcePath": "/",
+            "RequestInterval": 30,
+            "FailureThreshold": 123,
+            "HealthThreshold": 123,
+        },
+    )
+    healthcheck1_id = health_check1["HealthCheck"]["Id"]
+
+    health_check2 = conn.create_health_check(
+        CallerReference="bar",
+        HealthCheckConfig={
+            "IPAddress": "192.0.2.44",
+            "Port": 123,
+            "Type": "HTTP",
+            "ResourcePath": "/",
+            "RequestInterval": 30,
+            "FailureThreshold": 123,
+            "HealthThreshold": 123,
+        },
+    )
+    healthcheck2_id = health_check2["HealthCheck"]["Id"]
+
+    # confirm this works for resources with zero tags for hostedzone
+    response = conn.list_tags_for_resources(
+        ResourceIds=[zone1_id, zone2_id], ResourceType="hostedzone"
+    )
+
+    for set in response["ResourceTagSets"]:
+        assert set["Tags"] == []
+
+    # confirm this works for resources with zero tags for healthchecks
+    response = conn.list_tags_for_resources(
+        ResourceIds=[healthcheck1_id, healthcheck2_id], ResourceType="healthcheck"
+    )
+
+    for set in response["ResourceTagSets"]:
+        assert set["Tags"] == []
+
+    tag1 = {"Key": "Deploy", "Value": "True"}
+    tag2 = {"Key": "Name", "Value": "UnitTest"}
+    tag3 = {"Key": "Owner", "Value": "Alice"}
+    tag4 = {"Key": "License", "Value": "MIT"}
+
+    conn.change_tags_for_resource(
+        ResourceType="hostedzone", ResourceId=zone1_id, AddTags=[tag1, tag2]
+    )
+    conn.change_tags_for_resource(
+        ResourceType="hostedzone", ResourceId=zone2_id, AddTags=[tag3, tag4]
+    )
+
+    conn.change_tags_for_resource(
+        ResourceType="healthcheck", ResourceId=healthcheck1_id, AddTags=[tag1, tag2]
+    )
+    conn.change_tags_for_resource(
+        ResourceType="healthcheck", ResourceId=healthcheck2_id, AddTags=[tag3, tag4]
+    )
+
+    # Test hostedzone
+    response = conn.list_tags_for_resources(
+        ResourceIds=[zone1_id, zone2_id], ResourceType="hostedzone"
+    )
+    assert len(response["ResourceTagSets"]) == 2
+    for set in response["ResourceTagSets"]:
+        assert set["ResourceId"] in (zone1_id, zone2_id)
+        assert set["ResourceType"] == "hostedzone"
+        if set["ResourceId"] == zone1_id:
+            assert tag1 in set["Tags"]
+            assert tag2 in set["Tags"]
+            assert tag3 not in set["Tags"]
+            assert tag4 not in set["Tags"]
+        elif set["ResourceId"] == zone2_id:
+            assert tag1 not in set["Tags"]
+            assert tag2 not in set["Tags"]
+            assert tag3 in set["Tags"]
+            assert tag4 in set["Tags"]
+
+    # Test hostedzone with single resource
+    response = conn.list_tags_for_resources(
+        ResourceIds=[zone1_id], ResourceType="hostedzone"
+    )
+    assert len(response["ResourceTagSets"]) == 1
+    for set in response["ResourceTagSets"]:
+        assert set["ResourceId"] == zone1_id
+        assert set["ResourceType"] == "hostedzone"
+        assert tag1 in set["Tags"]
+        assert tag2 in set["Tags"]
+        assert tag3 not in set["Tags"]
+        assert tag4 not in set["Tags"]
+
+    # Test healthcheck
+    response = conn.list_tags_for_resources(
+        ResourceIds=[healthcheck1_id, healthcheck2_id], ResourceType="healthcheck"
+    )
+    assert len(response["ResourceTagSets"]) == 2
+    for set in response["ResourceTagSets"]:
+        assert set["ResourceId"] in (healthcheck1_id, healthcheck2_id)
+        assert set["ResourceType"] == "healthcheck"
+        if set["ResourceId"] == healthcheck1_id:
+            assert tag1 in set["Tags"]
+            assert tag2 in set["Tags"]
+            assert tag3 not in set["Tags"]
+            assert tag4 not in set["Tags"]
+        elif set["ResourceId"] == healthcheck2_id:
+            assert tag1 not in set["Tags"]
+            assert tag2 not in set["Tags"]
+            assert tag3 in set["Tags"]
+            assert tag4 in set["Tags"]
+
+
+@mock_aws
 def test_list_hosted_zones_by_name():
     # Create mock VPC so we can get a VPC ID
     ec2c = boto3.client("ec2", region_name="us-east-1")
@@ -552,7 +744,7 @@ def test_list_hosted_zones_by_name():
     assert zones["HostedZones"][2]["Name"] == "test.a.org."
 
 
-@mock_route53
+@mock_aws
 def test_list_hosted_zones_by_dns_name():
     conn = boto3.client("route53", region_name="us-east-1")
     conn.create_hosted_zone(
@@ -603,7 +795,45 @@ def test_list_hosted_zones_by_dns_name():
     assert zones["HostedZones"][3]["CallerReference"] == str(hash("bar"))
 
 
-@mock_route53
+@mock_aws
+def test_list_hosted_zones_pagination():
+    conn = boto3.client("route53", region_name="us-east-1")
+
+    for idx in range(150):
+        conn.create_hosted_zone(
+            Name=f"test{idx}.com.", CallerReference=str(hash(f"h{idx}"))
+        )
+
+    page1 = conn.list_hosted_zones()
+    assert "Marker" not in page1
+    assert page1["IsTruncated"] is True
+    assert "NextMarker" in page1
+    assert "MaxItems" not in page1
+    assert len(page1["HostedZones"]) == 100
+
+    page2 = conn.list_hosted_zones(Marker=page1["NextMarker"])
+    assert page2["Marker"] == page1["NextMarker"]
+    assert page2["IsTruncated"] is False
+    assert "NextMarker" not in page2
+    assert "MaxItems" not in page2
+    assert len(page2["HostedZones"]) == 50
+
+    small_page = conn.list_hosted_zones(MaxItems="75")
+    assert "Marker" not in small_page
+    assert small_page["IsTruncated"] is True
+    assert "NextMarker" in small_page
+    assert small_page["MaxItems"] == "75"
+    assert len(small_page["HostedZones"]) == 75
+
+    remainer = conn.list_hosted_zones(Marker=small_page["NextMarker"])
+    assert remainer["Marker"] == small_page["NextMarker"]
+    assert remainer["IsTruncated"] is False
+    assert "NextMarker" not in remainer
+    assert "MaxItems" not in remainer
+    assert len(remainer["HostedZones"]) == 75
+
+
+@mock_aws
 def test_change_resource_record_sets_crud_valid():
     conn = boto3.client("route53", region_name="us-east-1")
     conn.create_hosted_zone(
@@ -728,7 +958,7 @@ def test_change_resource_record_sets_crud_valid():
     assert len(response["ResourceRecordSets"]) == 2
 
 
-@mock_route53
+@mock_aws
 @pytest.mark.parametrize("multi_value_answer", [True, False, None])
 def test_change_resource_record_sets_crud_valid_with_special_xml_chars(
     multi_value_answer,
@@ -833,7 +1063,7 @@ def test_change_resource_record_sets_crud_valid_with_special_xml_chars(
     assert len(response["ResourceRecordSets"]) == 2
 
 
-@mock_route53
+@mock_aws
 def test_change_resource_record_set__delete_should_match_create():
     # To delete a resource record set, you must specify all the same values that you specified when you created it.
     client = boto3.client("route53", region_name="us-east-1")
@@ -868,7 +1098,7 @@ def test_change_resource_record_set__delete_should_match_create():
                         "Action": "DELETE",
                         "ResourceRecordSet": {
                             "Name": name,
-                            "Type": "A"
+                            "Type": "A",
                             # Missing TTL and ResourceRecords
                         },
                     }
@@ -883,7 +1113,7 @@ def test_change_resource_record_set__delete_should_match_create():
     )
 
 
-@mock_route53
+@mock_aws
 def test_change_weighted_resource_record_sets():
     conn = boto3.client("route53", region_name="us-east-2")
     conn.create_hosted_zone(
@@ -995,7 +1225,7 @@ def test_change_weighted_resource_record_sets():
                 assert record["Weight"] == 10
 
 
-@mock_route53
+@mock_aws
 def test_failover_record_sets():
     conn = boto3.client("route53", region_name="us-east-2")
     conn.create_hosted_zone(Name="test.zone.", CallerReference=str(hash("test")))
@@ -1026,7 +1256,7 @@ def test_failover_record_sets():
     assert record["Failover"] == "PRIMARY"
 
 
-@mock_route53
+@mock_aws
 def test_geolocation_record_sets():
     conn = boto3.client("route53", region_name="us-east-2")
     conn.create_hosted_zone(Name="test.zone.", CallerReference=str(hash("test")))
@@ -1068,7 +1298,7 @@ def test_geolocation_record_sets():
     assert rrs[3]["GeoLocation"] == {"CountryCode": "US", "SubdivisionCode": "NY"}
 
 
-@mock_route53
+@mock_aws
 def test_change_resource_record_invalid():
     conn = boto3.client("route53", region_name="us-east-1")
     conn.create_hosted_zone(
@@ -1129,7 +1359,7 @@ def test_change_resource_record_invalid():
     assert len(response["ResourceRecordSets"]) == 2
 
 
-@mock_route53
+@mock_aws
 def test_change_resource_record_invalid_action_value():
     conn = boto3.client("route53", region_name="us-east-1")
     conn.create_hosted_zone(
@@ -1174,7 +1404,7 @@ def test_change_resource_record_invalid_action_value():
     assert len(response["ResourceRecordSets"]) == 2
 
 
-@mock_route53
+@mock_aws
 def test_change_resource_record_set_create__should_fail_when_record_already_exists():
     ZONE = "cname.local"
     FQDN = f"test.{ZONE}"
@@ -1210,7 +1440,7 @@ def test_change_resource_record_set_create__should_fail_when_record_already_exis
     )
 
 
-@mock_route53
+@mock_aws
 def test_change_resource_record_set__should_create_record_when_using_upsert():
     route53_client = boto3.client("route53", region_name="us-east-1")
 
@@ -1252,7 +1482,7 @@ def test_change_resource_record_set__should_create_record_when_using_upsert():
     assert response["ResourceRecordSets"][2] == resource_record
 
 
-@mock_route53
+@mock_aws
 def test_list_resource_record_sets_name_type_filters():
     conn = boto3.client("route53", region_name="us-east-1")
     create_hosted_zone_response = conn.create_hosted_zone(
@@ -1310,7 +1540,7 @@ def test_list_resource_record_sets_name_type_filters():
         assert desired_record in returned_records
 
 
-@mock_route53
+@mock_aws
 def test_get_change():
     conn = boto3.client("route53", region_name="us-east-2")
 
@@ -1321,7 +1551,7 @@ def test_get_change():
     assert response["ChangeInfo"]["Status"] == "INSYNC"
 
 
-@mock_route53
+@mock_aws
 def test_change_resource_record_sets_records_limit():
     conn = boto3.client("route53", region_name="us-east-1")
     conn.create_hosted_zone(
@@ -1441,7 +1671,7 @@ def test_change_resource_record_sets_records_limit():
     assert err["Message"] == "Number of records limit of 1000 exceeded."
 
 
-@mock_route53
+@mock_aws
 def test_list_resource_recordset_pagination():
     conn = boto3.client("route53", region_name="us-east-1")
     conn.create_hosted_zone(
@@ -1507,7 +1737,7 @@ def test_list_resource_recordset_pagination():
     assert "NextRecordType" not in response
 
 
-@mock_route53
+@mock_aws
 def test_get_dns_sec():
     client = boto3.client("route53", region_name="us-east-1")
 
@@ -1518,7 +1748,7 @@ def test_get_dns_sec():
     assert dns_sec["Status"] == {"ServeSignature": "NOT_SIGNING"}
 
 
-@mock_route53
+@mock_aws
 @pytest.mark.parametrize(
     "domain1,domain2",
     (
@@ -1567,3 +1797,31 @@ def test_conflicting_domain_exists(domain1, domain2):
         CallerReference=str(hash("bar")),
         DelegationSetId="2",
     )
+
+
+@mock_aws
+@pytest.mark.skipif(
+    not settings.TEST_DECORATOR_MODE, reason="Can't access the id manager in proxy mode"
+)
+@pytest.mark.parametrize("delegation_set_id", ["delegation_identifier", None])
+def test_create_hosted_zone_with_custom_id(
+    delegation_set_id, set_custom_id, account_id
+):
+    static_hosted_zone_id = "JP7YCKDZ51I4XA8"
+    hosted_zone_name = f"{str(uuid.uuid4())[0:6]}.getmoto.com."
+    region_name = "us-east-1"
+    set_custom_id(
+        HostedZoneIdentifier(account_id, hosted_zone_name, delegation_set_id),
+        static_hosted_zone_id,
+    )
+
+    conn = boto3.client("route53", region_name)
+    payload = {
+        "Name": hosted_zone_name,
+        "CallerReference": str(hash("foo")),
+    }
+    if delegation_set_id:
+        payload["DelegationSetId"] = delegation_set_id
+    hosted_zone = conn.create_hosted_zone(**payload)
+
+    assert hosted_zone["HostedZone"]["Id"] == f"/hostedzone/{static_hosted_zone_id}"
