@@ -1,18 +1,21 @@
-"""Unit tests for scheduler-supported APIs."""
-from datetime import datetime
+from datetime import datetime, timezone
 
 import boto3
 import pytest
 from botocore.client import ClientError
 
-from moto import mock_scheduler
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID
+from tests.test_scheduler import (
+    pytest_parametrize_test_create_get_schedule__with_start_date,
+    pytest_parametrize_test_create_schedule__exception_with_start_date,
+)
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
 
 
-@mock_scheduler
+@mock_aws
 def test_create_get_schedule():
     client = boto3.client("scheduler", region_name="eu-west-1")
     arn = client.create_schedule(
@@ -26,6 +29,7 @@ def test_create_get_schedule():
             "Arn": "not supported yet",
             "RoleArn": "n/a",
         },
+        ActionAfterCompletion="DELETE",
     )["ScheduleArn"]
 
     assert (
@@ -41,6 +45,7 @@ def test_create_get_schedule():
         "MaximumWindowInMinutes": 4,
         "Mode": "OFF",
     }
+    assert resp["ActionAfterCompletion"] == "DELETE"
     assert resp["Target"] == {
         "Arn": "not supported yet",
         "RoleArn": "n/a",
@@ -51,7 +56,7 @@ def test_create_get_schedule():
     assert resp["CreationDate"] == resp["LastModificationDate"]
 
 
-@mock_scheduler
+@mock_aws
 def test_create_get_delete__in_different_group():
     client = boto3.client("scheduler", region_name="eu-west-1")
 
@@ -94,7 +99,7 @@ def test_create_get_delete__in_different_group():
     ],
     ids=["without_group", "with_group"],
 )
-@mock_scheduler
+@mock_aws
 def test_update_schedule(extra_kwargs):
     client = boto3.client("scheduler", region_name="eu-west-1")
 
@@ -145,7 +150,7 @@ def test_update_schedule(extra_kwargs):
     assert schedule["CreationDate"] != schedule["LastModificationDate"]
 
 
-@mock_scheduler
+@mock_aws
 def test_create_duplicate_schedule():
     client = boto3.client("scheduler", region_name="us-east-1")
     params = {
@@ -165,7 +170,7 @@ def test_create_duplicate_schedule():
     assert err["Message"] == "Schedule schedule1 already exists."
 
 
-@mock_scheduler
+@mock_aws
 def test_get_schedule_for_unknown_group():
     client = boto3.client("scheduler", region_name="eu-west-1")
 
@@ -175,7 +180,7 @@ def test_get_schedule_for_unknown_group():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_scheduler
+@mock_aws
 def test_get_schedule_for_none_existing_schedule():
     client = boto3.client("scheduler", region_name="eu-west-1")
 
@@ -184,9 +189,10 @@ def test_get_schedule_for_none_existing_schedule():
     err = exc.value.response["Error"]
     assert err["Code"] == "ResourceNotFoundException"
     assert err["Message"] == "Schedule my-schedule does not exist."
+    assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 404
 
 
-@mock_scheduler
+@mock_aws
 def test_list_schedules():
     client = boto3.client("scheduler", region_name="eu-west-1")
 
@@ -219,7 +225,7 @@ def test_list_schedules():
     assert len(schedules) == 4
 
 
-@mock_scheduler
+@mock_aws
 def test_delete_schedule_for_none_existing_schedule():
     client = boto3.client("scheduler", region_name="eu-west-1")
 
@@ -228,3 +234,67 @@ def test_delete_schedule_for_none_existing_schedule():
     err = exc.value.response["Error"]
     assert err["Code"] == "ResourceNotFoundException"
     assert err["Message"] == "Schedule my-schedule does not exist."
+
+
+@mock_aws
+@pytest.mark.parametrize(
+    "start_date,expected_start_date",
+    pytest_parametrize_test_create_get_schedule__with_start_date(),
+)
+def test_create_get_schedule__with_start_date(start_date, expected_start_date):
+    # Act
+    client = boto3.client("scheduler", region_name="eu-west-1")
+    client.create_schedule(
+        StartDate=start_date,
+        Name="my-schedule",
+        ScheduleExpression="some cron *",
+        FlexibleTimeWindow={
+            "MaximumWindowInMinutes": 4,
+            "Mode": "OFF",
+        },
+        Target={
+            "Arn": "not supported yet",
+            "RoleArn": "n/a",
+        },
+    )
+
+    # Assert
+    resp = client.get_schedule(Name="my-schedule")
+    start_date_as_utc = datetime.astimezone(resp["StartDate"], timezone.utc).replace(
+        tzinfo=None
+    )
+    assert start_date_as_utc == expected_start_date
+
+
+@mock_aws
+@pytest.mark.parametrize(
+    "start_date",
+    pytest_parametrize_test_create_schedule__exception_with_start_date(),
+)
+def test_create_schedule__exception_with_start_date(start_date):
+    # Arrange
+    expected_error = "ValidationException"
+    expected_error_message = (
+        "The StartDate you specify cannot be earlier than 5 minutes ago."
+    )
+    # Act
+    with pytest.raises(ClientError) as exc:
+        client = boto3.client("scheduler", region_name="eu-west-1")
+        client.create_schedule(
+            Name="my-schedule",
+            StartDate=start_date,
+            ScheduleExpression="some cron *",
+            FlexibleTimeWindow={
+                "MaximumWindowInMinutes": 4,
+                "Mode": "OFF",
+            },
+            Target={
+                "Arn": "not supported yet",
+                "RoleArn": "n/a",
+            },
+        )
+
+    # Assert
+    err = exc.value.response["Error"]
+    assert err["Code"] == expected_error
+    assert err["Message"] == expected_error_message
